@@ -1,7 +1,7 @@
 miniumDeveloper.factory('FeaturePreviewService', function($http) {
     return {
         preview: function(params) {
-            return $http.post("/app/rest/preview",params);
+            return $http.post("app/rest/preview",params);
         }
     };
 })
