@@ -3,7 +3,7 @@
 miniumDeveloper.factory('RecorderService', function($http) {
     return {
         getScript: function() {
-            return $http.get("/app/rest/recorder/script");
+            return $http.get("app/rest/recorder/script");
         }
     };
 });
